# shippy
![version](https://img.shields.io/github/v/release/ericswpark/shippy)
![commits-since](https://img.shields.io/github/commits-since/ericswpark/shippy/latest)
[
![PyPI](https://img.shields.io/pypi/v/shipper-shippy)
![PyPI - Downloads](https://img.shields.io/pypi/dm/shipper-shippy)
](https://pypi.org/project/shipper-shippy/)

Client-side tool to interface with shipper

# Usage

Get shippy from PyPI:

```shell
pip3 install shipper-shippy
```

Go to the directory with build files, and run:

```shell
shippy
```
